<div align="center">
<h1>
  ByteTrack-Pip: Packaged version of the ByteTrack repository  
</h1>
<h4>
    <img width="700" alt="teaser" src="assets/demo.gif">
</h4>
</div>

## <div align="center">Overview</div>

This repo is a packaged version of the [ByteTrack](https://github.com/ifzhang/ByteTrack) algorithm.
### Installation
```
pip install bytetracker
```

### Detection Model + ByteTrack 
```python

```
### Reference:
 - [Yolov5-Pip](https://github.com/fcakyon/yolov5-pip)
 - [ByteTrack](https://github.com/ifzhang/ByteTrack)

### Citation
```bibtex
@article{zhang2022bytetrack,
  title={ByteTrack: Multi-Object Tracking by Associating Every Detection Box},
  author={Zhang, Yifu and Sun, Peize and Jiang, Yi and Yu, Dongdong and Weng, Fucheng and Yuan, Zehuan and Luo, Ping and Liu, Wenyu and Wang, Xinggang},
  booktitle={Proceedings of the European Conference on Computer Vision (ECCV)},
  year={2022}
}
```
